Scheme Node (node)

# Scheme Node (`node`)

## Scheme Node

class `orangecanvas.scheme.node.` `SchemeNode`(description, title=None, position=None, properties=None, parent=None)

  Bases: `PyQt5.QtCore.QObject`

  A node in a `Scheme`.

  Parameters: | description (`WidgetDescription`) – Node description instance. title (str, optional) – Node title string (if None description.name is used). position (tuple) – (x, y) tuple of floats for node position in a visual display. properties (dict) – Additional extra instance properties (settings, widget geometry, …) parent (`QObject`) – Parent object.

  `title_changed`(title)

    The title of the node has changed

  `position_changed`((x, y))

    Position of the node in the scheme has changed

  `progress_changed`(progress)

    Node’s progress value has changed.

  `processing_state_changed`(state)

    Node’s processing state has changed.

  `input_channels`()

    Return a list of input channels (`InputSignal`) for the node.

  `output_channels`()

    Return a list of output channels (`OutputSignal`) for the node.

  `input_channel`(name)

    Return the input channel matching name. Raise a ValueError if not found.

  `output_channel`(name)

    Return the output channel matching name. Raise an ValueError if not found.

  `set_title`(title)

    Set the node title.

  `title`

    The node title.

  `set_position`(pos)

    Set the position (`(x, y)` tuple) of the node.

  `position`

    `(x, y)` tuple containing the position of the node in the scheme.

  `set_progress`(value)

    Set the progress value.

  `progress`

    The current progress value. -1 if progress is not set.

  `set_processing_state`(state)

    Set the node processing state.

  `processing_state`

    The node processing state, 0 for not processing, 1 the node is busy.

  `status_message_changed`

    The node’s status tip has changes

  `state_message_changed`

    The node’s state message has changed

  `set_state_message`(message)

    Set a message to be displayed by a scheme view for this node.

  `state_messages`()

    Return a list of all state messages.